import asyncio
import os

from telethon import TelegramClient

TELETHON_SESSION_FILE: os.path = input("Please insert path to telethon session file: ")
API_ID: int = int(input("Please insert session api id: "))
API_HASH: str = input("Please insert session api hash: ")
TG_USERNAME_RECIPIENT: str = input(
    "Please insert telegram username recipient fro test message: "
)


async def check_telethon():
    async with TelegramClient(
        TELETHON_SESSION_FILE, api_id=API_ID, api_hash=API_HASH
    ) as client:
        await client.send_message(TG_USERNAME_RECIPIENT, "Client success work!")


if __name__ == "__main__":
    asyncio.run(check_telethon())



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['tele-pyro', 'tele-pyro.utils']

package_data = \
{'': ['*']}

install_requires = \
['Pyrogram>=1.4.8,<2.0.0', 'Telethon>=1.24.0,<2.0.0', 'TgCrypto>=1.2.3,<2.0.0']

entry_points = \
{'console_scripts': ['tele-pyro = __main__:main']}

setup_kwargs = {
    'name': 'tele-pyro',
    'version': '0.1.1.5',
    'description': 'Script for convert telethon sesession file to pyrogram session file',
    'long_description': '<h1>Telethon to Pyrogram</h1>\nPyPi\nIsort\nTest\nLint\nlicense\nGitter\nDownloads\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n\n<h4>Simple script for convert telethon session file to pyrogram session file</h4>\n\n<h3>For use:</h3>\n\n1. Clone repo `git clone git@github.com:semenovsd/Telethon-To-Pyrogram.git`\n2. Install Telethon and Pyrogram `poetry install` or user pip `pip install Telethon Pyrogram`\n3. Run convertor.py `python convertor.py` and follow instructions\n',
    'author': 'Stanislav Semenov',
    'author_email': 'semenov_sd@bk.ru',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/semenovsd/Telethon-To-Pyrogram',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '==3.9.4',
}


setup(**setup_kwargs)
